@@ -3,6 +3,7 @@ from __future__ import absolute_import, division, print_function
 import re
 import json
 import datetime
+from datetime import timezone
 import base64
 import logging
 import os
@@ -109,7 +110,7 @@ def fromNow(offset, dateObj=None):
     )
 
     if not dateObj:
-        dateObj = datetime.datetime.utcnow()
+        dateObj = datetime.datetime.now(timezone.utc)
 
     return dateObj + delta if future else dateObj - delta
 
@@ -122,7 +123,7 @@ def fromNowJSON(offset):
 
 
 def dumpJson(obj, **kwargs):
-    """ Match JS's JSON.stringify.  When using the default seperators,
+    """ Match JS's JSON.stringify.  When using the default separators,
     base64 encoding JSON results in \n sequences in the output.  Hawk
     barfs in your face if you have that in the text"""
     def handleDateAndBinaryForJs(x):
@@ -216,10 +217,10 @@ def scopeMatch(assumedScopes, requiredScopeSets):
         for requiredScope in scopeSet:
             for scope in assumedScopes:
                 if scope == requiredScope:
-                    # requiredScope satisifed, no need to check more scopes
+                    # requiredScope satisfied, no need to check more scopes
                     break
                 if scope.endswith("*") and requiredScope.startswith(scope[:-1]):
-                    # requiredScope satisifed, no need to check more scopes
+                    # requiredScope satisfied, no need to check more scopes
                     break
             else:
                 # requiredScope not satisfied, stop checking scopeSet
@@ -261,7 +262,7 @@ def makeHttpRequest(method, url, payload, headers, retries=MAX_RETRIES, session=
             response = makeSingleHttpRequest(method, url, payload, headers, session)
         except requests.exceptions.RequestException as rerr:
             if retry < retries:
-                log.warn('Retrying because of: %s' % rerr)
+                log.warning('Retrying because of: %s' % rerr)
                 continue
             # raise a connection exception
             raise rerr
@@ -273,7 +274,7 @@ def makeHttpRequest(method, url, payload, headers, retries=MAX_RETRIES, session=
         status = response.status_code
         if 500 <= status and status < 600 and retry < retries:
             if retry < retries:
-                log.warn('Retrying because of: %d status' % status)
+                log.warning('Retrying because of: %d status' % status)
                 continue
             else:
                 raise exceptions.TaskclusterRestFailure("Unknown Server Error", superExc=None)
